@@ -3,11 +3,15 @@ import numpy as np
 import pandas as pd
 from scipy.stats import spearmanr
 from sklearn.linear_model import Ridge
-from MLE_augmentor import FIESTA
 from sklearn.metrics import roc_auc_score
 from sklearn.preprocessing import LabelBinarizer
-from customize_regressor import GD_regressor
 from sksurv.metrics import concordance_index_censored
+try:
+    from MLE_augmentor import FIESTA
+    from customize_regressor import GD_regressor
+except:
+    from src.MLE_augmentor import FIESTA
+    from src.customize_regressor import GD_regressor
 
 
 
@@ -39,7 +43,7 @@ class LBL:
     """
     suRvival Analysis lefT barrIer lOss (RATIO) and DA combined with Ridge regression
     Minimizes the objective function of:
-    Sum on uncensored(||w*x_i -Te_i||^2) + Sum on censored(||w*x_i-Tc_i||^2*I(w*x_i < Tc_i))
+    Sum on uncensored(||w*x_i -Te_i||^2-w*xi/tau) + Sum on censored(||w*x_i-Tc_i||^2*I(w*x_i < Tc_i))
     This model solves a regression model where the loss function is the linear least squares function
     for the uncensored data and a linear left barrier loss for the wrong censored samples.
     The user can moderate the relations between the censored and uncensored loss.
